# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [4.1.1]
### Changed
- Handle >= 3.78.0 nexus versions

## [4.1.0]
### Added
- Add parameter for postgresql datastore

### Changed
- Handle >= 3.71.0 nexus versions
- Allow puppet/extlib < 8.0.0

## [4.0.0]
### Added
- Extended test suite to puppet 8
- Add docker subdomain connector parameter
- `nexus::resource::repository::rubygems::proxy` to manage rubygems proxy repositories
- `nexus::resource::repository::raw::hosted` to manage raw hosted repositories
- `nexus::resource::repository::pypi::proxy` to manage pypi proxy repositories
- `cleanup_policy_names` added to all repository types
- Option to install nexus by package
- Option to set java runtime version (nexus >= 3.67.0-03)

### Changed
- PDK version to 3.0.0
- Codestyle adjustmensts

### Removed
- Support for end of life puppet 6

## [3.5.0]
### Added
- `docker_subdomain` in `nexus::resource::repository::docker::proxy`
- `docker_proxy_cache_foreign_layers` in `nexus::resource::repository::docker::proxy`
- `docker_proxy_foreign_layer_url_whitelist` in `nexus::resource::repository::docker::proxy`

### Changed
- Changes by `pdk update`
- Changes by `pdk validate -a`
- Updated `README.md` to reflect current module usage

### Removed
- Unused `npm_remove_non_cataloged` in `nexus::resource::repository::docker::proxy`
- Unused `npm_remove_quarantined` in `nexus::resource::repository::docker::proxy`

## [3.4.0]
### Added
- `nexus::resource::repository::yum::hosted` to manage yum hosted repositories
- `nexus::resource::repository::yum::proxy` to manage yum proxy repositories

### Changed
- Updated module dependencies
- `nexus::config::admin::password` changed to allow `Sensitive` datatype
- `nexus::resource::repository::apt::proxy` to allow http urls

## [3.3.0]
### Added
- Invalidate cache on changes of repository types `group` and `proxy`
- Rebuild index on changes of repository types `hosted` and `proxy`
- `nexus::resource::repository::docker::group` to manage docker group repositories
- `nexus::resource::repository::docker::hosted` to manage docker hosted repositories
- `nexus::resource::repository::docker::proxy` to manage docker proxy repositories

## [3.2.0]
### Added
- `nexus::manage_api_resources` to setup configuration to connect to nexus repository manager rest api
- `nexus::purge_default_repositories` to remove default maven and nuget repositories
- `nexus::config::email` to configure email settings
- `nexus::config::anonymous` to configure an anonymous access
- `nexus::config::admin` to configure administrator account
- `nexus::resource::blobstore::file` to manage blobstores of type file
- `nexus::resource::repository::apt::proxy` to manage apt proxy repositories
- `nexus::resource::repository::npm::group` to manage npm group repositories
- `nexus::resource::repository::npm::hosted` to manage npm hosted repositories
- `nexus::resource::repository::npm::proxy` to manage npm proxy repositories

### Changed
- `nexus::config` moved to `nexus::config::properties`
- systemd service file adjusted to wait until nexus repository manager finished startup

## [3.1.0]
### Added
- `nexus::plugin::composer` to install composer (php) repository plugin

## [3.0.0]
### Added
- `REFERENCE.md` generated by `puppet strings generate --format markdown --out REFERENCE.md`
- `purge_old_installation` to delete old Nexus Repository Manager installations
- `~/.java/.userPrefs` creation to prevent `Couldn't flush user prefs`-error

### Changed
- Variable names in `init.pp` no longer contain `nexus` as it's already the module name.
- User and group creation moved to `user.pp`
- Default installation path changed from `/srv` to `/opt/sonatype`
- Default bind address changed from `0.0.0.0` to `127.0.0.1`

### Removed
- Support for Nexus Repository Manager 2

## [2.0.0]
### Added
- Add proper data types for module parameter

### Changed
- Http download urls to https
- `params.pp` pattern to hiera lookup
- Change nexus_port from data type string to integer (Stdlib::Port)

### Removed
- `version` parameter from `nexus::service` class as it is not used
- `md5sum` parameter from `nexus` class as it is not used (checksum source depends on download url)
- Nexus Repository Manager 2 example - next major version will drop support for that version
- Support for end of life puppet versions

## [1.9.2]
### Added
- Allow proxy use to download the archive

## [1.9.1]
### Added
- Set file recurse variable for nexus_home_real

## [1.9.0]
### Added
- Updated [README.md](README.md)
- Dropped end of life distributions
- Updated module dependencies
- Extended test suite to puppet 7
- Fix too wide match strings - [issue #8](https://github.com/puppets-epic-show-theatre/puppet-nexus/issues/9)
- Changes by `pdk update`

## [1.8.0]
### Changed
- Replaced obsolete `puppet/wget` module by [puppet/archive](https://github.com/voxpupuli/puppet-archive)
- Nexus artifact downloads get always validated against published md5 sum - md5sum parameter is currently getting ignored

## [1.7.5]
### Added
- `.sync.yml` for `pdk update`

### Changed
- Extended test suite to puppet 5 and puppet 6
- Fix test suite
- Updated README.md and metadata.json

## [1.7.4]
### Changed
- Replaced obsolete `maestrodev/wget` module by [puppet/wget](https://github.com/voxpupuli/puppet-wget)
- Initial `pdk convert` changes
- Adjust module requirements in [metadata.json](metadata.json)

## [1.7.1]
### Added
- Support for validating the md5 checksum of the Nexus package file. https://github.com/hubspotdevops/puppet-nexus/pull/80

## [1.7.0]
### Added
- Support for CentOS and RedHat versions using systemd: https://github.com/hubspotdevops/puppet-nexus/pull/76

## [1.6.1]
### Added
- Support for older versions of Ubuntu: https://github.com/hubspotdevops/puppet-nexus/pull/70

## [1.6.0]
### Added
- Support for Ubuntu https://github.com/hubspotdevops/puppet-nexus/pull/67

## [1.5.0]
### Added
- Support for Puppet 4.5.2 https://github.com/hubspotdevops/puppet-nexus/pull/65

## [1.4.0]
### Added
- Support for Nexus 3
- Support for Debian 8

## [1.3.1]
### Changed
- Fix the location of the Nexus work directory if $nexus_work_dir is not passed in.

## [1.3.0]
### Added
- Make $nexus_work_dir configurable instead of using "${nexus_root}/${nexus::params::nexus_work_dir}" (/srv/sonatype-work)
- Make managing owner and perms of $nexus_work_dir configurable.
  - installations with large repos can turn this off to prevent overconsumption of resources.
  - This has been requested for ages.
- Add rudimentary spec tests

### Changed
- Updated download location of package.
- Set 'run_as_user' for service status to $nexus_user.  A bug from 2.7 days appears to be gone.
