# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`nexus`](#nexus): Install and configure Sonatype Nexus Repository Manager 3.
* [`nexus::config::admin`](#nexus--config--admin): Manage the nexus repository manager administrator account
* [`nexus::config::anonymous`](#nexus--config--anonymous): Manage if anonymous user have access to nexus repository manager
* [`nexus::config::default_repositories`](#nexus--config--default_repositories): Removes the default repositories for maven and nuget
* [`nexus::config::device`](#nexus--config--device): Create puppet device config used to connect to the rest api
* [`nexus::config::email`](#nexus--config--email): Manage the nexus repository manager email settings
* [`nexus::config::postgresql_datastore`](#nexus--config--postgresql_datastore): Manage the nexus postgresql datastore settings
* [`nexus::config::properties`](#nexus--config--properties): A short summary of the purpose of this class
* [`nexus::plugin::composer`](#nexus--plugin--composer): Install the composer repository format plugin

#### Private Classes

* `nexus::config`: Configure nexus repository manager
* `nexus::package`: Install the Nexus Repository Manager package
* `nexus::plugin`: Base class used by plugin classes
* `nexus::service`: Maintains the Nexus service
* `nexus::user`: Manages the operation system user account which is used to start up the service

### Defined types

* [`nexus::resource::blobstore::file`](#nexus--resource--blobstore--file): Resource to manage (local) file blobstore
* [`nexus::resource::repository::apt::proxy`](#nexus--resource--repository--apt--proxy): Resource to manage apt proxy repository
* [`nexus::resource::repository::docker::group`](#nexus--resource--repository--docker--group): Resource to manage docker group repository
* [`nexus::resource::repository::docker::hosted`](#nexus--resource--repository--docker--hosted): Resource to manage docker hosted repository
* [`nexus::resource::repository::docker::proxy`](#nexus--resource--repository--docker--proxy): Resource to manage docker proxy repository
* [`nexus::resource::repository::npm::group`](#nexus--resource--repository--npm--group): Resource to manage npm group repository
* [`nexus::resource::repository::npm::hosted`](#nexus--resource--repository--npm--hosted): Resource to manage npm hosted repository
* [`nexus::resource::repository::npm::proxy`](#nexus--resource--repository--npm--proxy): Resource to manage npm proxy repository
* [`nexus::resource::repository::pypi::proxy`](#nexus--resource--repository--pypi--proxy): Resource to manage PyPi proxy repository
* [`nexus::resource::repository::raw::hosted`](#nexus--resource--repository--raw--hosted): Resource to manage raw hosted repository
* [`nexus::resource::repository::rubygems::proxy`](#nexus--resource--repository--rubygems--proxy): Resource to manage RubyGems proxy repository
* [`nexus::resource::repository::yum::hosted`](#nexus--resource--repository--yum--hosted): Resource to manage yum hosted repository
* [`nexus::resource::repository::yum::proxy`](#nexus--resource--repository--yum--proxy): Resource to manage yum proxy repository

### Resource types

* [`nexus_blobstore`](#nexus_blobstore): Raw provider to configure blobstore over the nexus repository manager rest api.  Please use the defined types instead of this one directly.
* [`nexus_repository`](#nexus_repository): Raw provider to configure repository over the nexus repository manager rest api.  Please use the defined types instead of this one directly.
* [`nexus_role`](#nexus_role): Manage nexus repository roles
* [`nexus_setting`](#nexus_setting): Raw provider to set settings over the nexus repository manager rest api.  Please use nexus::config::* classes instead of this one directly.
* [`nexus_user`](#nexus_user): Manage nexus repository users

## Classes

### <a name="nexus"></a>`nexus`

Install and configure Sonatype Nexus Repository Manager 3.

* **See also**
  * https://help.sonatype.com/repomanager3/product-information/download/download-archives---repository-manager-3

#### Examples

##### 

```puppet
class{ 'nexus':
  version => '3.37.3-02',
}
```

#### Parameters

The following parameters are available in the `nexus` class:

* [`download_folder`](#-nexus--download_folder)
* [`download_site`](#-nexus--download_site)
* [`install_root`](#-nexus--install_root)
* [`work_dir`](#-nexus--work_dir)
* [`user`](#-nexus--user)
* [`group`](#-nexus--group)
* [`host`](#-nexus--host)
* [`port`](#-nexus--port)
* [`manage_api_resources`](#-nexus--manage_api_resources)
* [`manage_config`](#-nexus--manage_config)
* [`manage_user`](#-nexus--manage_user)
* [`manage_work_dir`](#-nexus--manage_work_dir)
* [`manage_datastore`](#-nexus--manage_datastore)
* [`purge_installations`](#-nexus--purge_installations)
* [`purge_default_repositories`](#-nexus--purge_default_repositories)
* [`package_type`](#-nexus--package_type)
* [`package_ensure`](#-nexus--package_ensure)
* [`download_proxy`](#-nexus--download_proxy)
* [`version`](#-nexus--version)
* [`java_runtime`](#-nexus--java_runtime)
* [`package_name`](#-nexus--package_name)
* [`postgresql_username`](#-nexus--postgresql_username)
* [`postgresql_password`](#-nexus--postgresql_password)
* [`postgresql_jdbcurl`](#-nexus--postgresql_jdbcurl)

##### <a name="-nexus--download_folder"></a>`download_folder`

Data type: `Stdlib::Absolutepath`

Destination folder of the downloaded archive.

##### <a name="-nexus--download_site"></a>`download_site`

Data type: `Stdlib::HTTPUrl`

Download uri which will be appended with filename of the archive to download.

##### <a name="-nexus--install_root"></a>`install_root`

Data type: `Stdlib::Absolutepath`

The root filesystem path where the downloaded archive will be extracted to.

##### <a name="-nexus--work_dir"></a>`work_dir`

Data type: `Stdlib::Absolutepath`

The nexus repository manager working directory which contains the embedded database and local blobstores.

##### <a name="-nexus--user"></a>`user`

Data type: `String[1]`

The operation system user used to start the nexus repository manager service.

##### <a name="-nexus--group"></a>`group`

Data type: `String[1]`

The operation system group used to start the nexus repository manager service.

##### <a name="-nexus--host"></a>`host`

Data type: `Stdlib::Host`

The bind address where the nexus repository manager service should bind to.

##### <a name="-nexus--port"></a>`port`

Data type: `Stdlib::Port`

The port which the nexus repository manager service should use.

##### <a name="-nexus--manage_api_resources"></a>`manage_api_resources`

Data type: `Boolean`

Set if this module should manage resources which require to be set over the nexus repository manager rest api.

##### <a name="-nexus--manage_config"></a>`manage_config`

Data type: `Boolean`

Set if this module should manage the config file of nexus repository manager.

##### <a name="-nexus--manage_user"></a>`manage_user`

Data type: `Boolean`

Set if this module should manage the creation of the operation system user.

##### <a name="-nexus--manage_work_dir"></a>`manage_work_dir`

Data type: `Boolean`

Set if this module should manage the work directory of the nexus repository manager.

##### <a name="-nexus--manage_datastore"></a>`manage_datastore`

Data type: `Boolean`

Set if this module should manage datastore - Note that you need a licence for postgresql backend

##### <a name="-nexus--purge_installations"></a>`purge_installations`

Data type: `Boolean`

Set this option if you want old installations of nexus repository manager to get automatically deleted.

##### <a name="-nexus--purge_default_repositories"></a>`purge_default_repositories`

Data type: `Boolean`

Set this option if you want to remove the default created maven and nuget repositories.

##### <a name="-nexus--package_type"></a>`package_type`

Data type: `Enum['src', 'pkg']`

Select 'src' for Source download & install. 'pkg' will fetch te specified package and version
from repos you must provide.

##### <a name="-nexus--package_ensure"></a>`package_ensure`

Data type: `String`

The version to install. See https://puppet.com/docs/puppet/7/types/package.html#package-attribute-ensure

##### <a name="-nexus--download_proxy"></a>`download_proxy`

Data type: `Optional[Stdlib::HTTPUrl]`

Proxyserver address which will be used to download the archive file.

Default value: `undef`

##### <a name="-nexus--version"></a>`version`

Data type: `Optional[Pattern[/3.\d+.\d+-\d+/]]`

The version to download, install and manage.

Default value: `undef`

##### <a name="-nexus--java_runtime"></a>`java_runtime`

Data type: `Optional[Enum['java8', 'java11']]`

The Java runtime to be utilized. Relevant only for Nexus versions >= 3.67.0-03 and < 3.71.0.

Default value: `undef`

##### <a name="-nexus--package_name"></a>`package_name`

Data type: `Optional[String]`

The name of the package to install. Default 'nexus'

Default value: `undef`

##### <a name="-nexus--postgresql_username"></a>`postgresql_username`

Data type: `Optional[String[1]]`

Postgresql Username - Only available in Sonatype Nexus Repository Pro

Default value: `undef`

##### <a name="-nexus--postgresql_password"></a>`postgresql_password`

Data type: `Optional[String[1]]`

Postgresql Password - Only available in Sonatype Nexus Repository Pro

Default value: `undef`

##### <a name="-nexus--postgresql_jdbcurl"></a>`postgresql_jdbcurl`

Data type: `Optional[String[1]]`

Postgresql jdbcUrl. Formatted as jdbc\:postgresql\://<database-host>\:<database-port>/nexus
Only available in Sonatype Nexus Repository Pro

Default value: `undef`

### <a name="nexus--config--admin"></a>`nexus::config::admin`

Manage the nexus repository manager administrator account

#### Examples

##### 

```puppet
include nexus::config::admin
```

#### Parameters

The following parameters are available in the `nexus::config::admin` class:

* [`username`](#-nexus--config--admin--username)
* [`first_name`](#-nexus--config--admin--first_name)
* [`last_name`](#-nexus--config--admin--last_name)
* [`email_address`](#-nexus--config--admin--email_address)
* [`roles`](#-nexus--config--admin--roles)
* [`password`](#-nexus--config--admin--password)

##### <a name="-nexus--config--admin--username"></a>`username`

Data type: `String[1]`

The username of the administrator.

Default value: `'admin'`

##### <a name="-nexus--config--admin--first_name"></a>`first_name`

Data type: `String[1]`

The first name of the administrator.

Default value: `'Administrator'`

##### <a name="-nexus--config--admin--last_name"></a>`last_name`

Data type: `String[1]`

The last name of the administrator.

Default value: `'User'`

##### <a name="-nexus--config--admin--email_address"></a>`email_address`

Data type: `String[1]`

The email address of the administrator.

Default value: `'admin@example.org'`

##### <a name="-nexus--config--admin--roles"></a>`roles`

Data type: `Array[String[1]]`

The assigned roles of the administrator. It should include 'nx-admin'.

Default value: `['nx-admin']`

##### <a name="-nexus--config--admin--password"></a>`password`

Data type: `Optional[Variant[String[1], Sensitive[String[1]]]]`

The password of the administrator. If not given there will be generated a random password.

Default value: `undef`

### <a name="nexus--config--anonymous"></a>`nexus::config::anonymous`

Manage if anonymous user have access to nexus repository manager

#### Examples

##### 

```puppet
include nexus::config::anonymous
```

#### Parameters

The following parameters are available in the `nexus::config::anonymous` class:

* [`enabled`](#-nexus--config--anonymous--enabled)
* [`user_id`](#-nexus--config--anonymous--user_id)
* [`realm_name`](#-nexus--config--anonymous--realm_name)

##### <a name="-nexus--config--anonymous--enabled"></a>`enabled`

Data type: `Boolean`

Enable if anonymous/not logged in user have access to nexus repository manager.

Default value: `false`

##### <a name="-nexus--config--anonymous--user_id"></a>`user_id`

Data type: `String[1]`

The nexus repository manager user id/name used to determine access.

Default value: `'anonymous'`

##### <a name="-nexus--config--anonymous--realm_name"></a>`realm_name`

Data type: `String[1]`

Realm name used for anonymous user.

Default value: `'NexusAuthorizingRealm'`

### <a name="nexus--config--default_repositories"></a>`nexus::config::default_repositories`

Removes the default repositories for maven and nuget

#### Examples

##### 

```puppet
include nexus::config::default_repositories
```

### <a name="nexus--config--device"></a>`nexus::config::device`

Create puppet device config used to connect to the rest api

### <a name="nexus--config--email"></a>`nexus::config::email`

Manage the nexus repository manager email settings

#### Examples

##### 

```puppet
include nexus::config::email
```

#### Parameters

The following parameters are available in the `nexus::config::email` class:

* [`enabled`](#-nexus--config--email--enabled)
* [`host`](#-nexus--config--email--host)
* [`port`](#-nexus--config--email--port)
* [`username`](#-nexus--config--email--username)
* [`password`](#-nexus--config--email--password)
* [`from_address`](#-nexus--config--email--from_address)
* [`subject_prefix`](#-nexus--config--email--subject_prefix)
* [`start_tls_enabled`](#-nexus--config--email--start_tls_enabled)
* [`start_tls_required`](#-nexus--config--email--start_tls_required)
* [`ssl_on_connect_enabled`](#-nexus--config--email--ssl_on_connect_enabled)
* [`ssl_server_identity_check_enabled`](#-nexus--config--email--ssl_server_identity_check_enabled)
* [`nexus_trust_store_enabled`](#-nexus--config--email--nexus_trust_store_enabled)

##### <a name="-nexus--config--email--enabled"></a>`enabled`

Data type: `Boolean`

Enable to let nexus repository manager send emails.

Default value: `false`

##### <a name="-nexus--config--email--host"></a>`host`

Data type: `Stdlib::Host`

The smtp host to connect to.

Default value: `'localhost'`

##### <a name="-nexus--config--email--port"></a>`port`

Data type: `Stdlib::Port`

The port to connect to send emails.

Default value: `25`

##### <a name="-nexus--config--email--username"></a>`username`

Data type: `String`

The username to connect to the smtp server.

Default value: `''`

##### <a name="-nexus--config--email--password"></a>`password`

Data type: `Optional[String[1]]`

The password to connect to the smtp server.

Default value: `undef`

##### <a name="-nexus--config--email--from_address"></a>`from_address`

Data type: `String[1]`

The email address used to set as From-Header.

Default value: `'nexus@example.org'`

##### <a name="-nexus--config--email--subject_prefix"></a>`subject_prefix`

Data type: `Optional[String[1]]`

Prefix which will be added to all emails.

Default value: `undef`

##### <a name="-nexus--config--email--start_tls_enabled"></a>`start_tls_enabled`

Data type: `Boolean`

Enable STARTTLS support for insecure connections.

Default value: `false`

##### <a name="-nexus--config--email--start_tls_required"></a>`start_tls_required`

Data type: `Boolean`

Require STARTTLS support.

Default value: `false`

##### <a name="-nexus--config--email--ssl_on_connect_enabled"></a>`ssl_on_connect_enabled`

Data type: `Boolean`

Enable SSL/TLS encryption upon connection.

Default value: `false`

##### <a name="-nexus--config--email--ssl_server_identity_check_enabled"></a>`ssl_server_identity_check_enabled`

Data type: `Boolean`

Enable server identity check.

Default value: `false`

##### <a name="-nexus--config--email--nexus_trust_store_enabled"></a>`nexus_trust_store_enabled`

Data type: `Boolean`

Use certificates stored in the Nexus truststore to connect to external systems.

Default value: `false`

### <a name="nexus--config--postgresql_datastore"></a>`nexus::config::postgresql_datastore`

Only available in Sonatype Nexus Repository Pro

### <a name="nexus--config--properties"></a>`nexus::config::properties`

A description of what this class does

#### Examples

##### 

```puppet
include nexus::config::properties
```

### <a name="nexus--plugin--composer"></a>`nexus::plugin::composer`

Install the composer repository format plugin

#### Examples

##### 

```puppet
class { 'nexus':
   version => '3.34.3-02',
}
class { 'nexus::plugin::composer':
   version => '0.0.18',
}
```

#### Parameters

The following parameters are available in the `nexus::plugin::composer` class:

* [`version`](#-nexus--plugin--composer--version)

##### <a name="-nexus--plugin--composer--version"></a>`version`

Data type: `Pattern[/\d+.\d+.\d+/]`

The composer repository format plugin version.

## Defined types

### <a name="nexus--resource--blobstore--file"></a>`nexus::resource::blobstore::file`

Resource to manage (local) file blobstore

#### Examples

##### 

```puppet
nexus::blobstore::file { 'apt-hosted': }
```

#### Parameters

The following parameters are available in the `nexus::resource::blobstore::file` defined type:

* [`ensure`](#-nexus--resource--blobstore--file--ensure)
* [`path`](#-nexus--resource--blobstore--file--path)

##### <a name="-nexus--resource--blobstore--file--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent

Default value: `'present'`

##### <a name="-nexus--resource--blobstore--file--path"></a>`path`

Data type: `Variant[Stdlib::Absolutepath, String[1]]`

The (local) path of the disk where the content of the blobstore should be stored. Non absolute paths will use the
working directory as base path. The nexus (service) user needs write access to this path.

Default value: `$title`

### <a name="nexus--resource--repository--apt--proxy"></a>`nexus::resource::repository::apt::proxy`

Resource to manage apt proxy repository

#### Examples

##### 

```puppet
nexus::repository::apt::proxy { 'apt-debian':
   apt_distribution => $facts['os']['distro']['codename'],
   proxy_remote_url => 'https://deb.debian.org/debian/',
}
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::apt::proxy` defined type:

* [`apt_distribution`](#-nexus--resource--repository--apt--proxy--apt_distribution)
* [`proxy_remote_url`](#-nexus--resource--repository--apt--proxy--proxy_remote_url)
* [`apt_flat`](#-nexus--resource--repository--apt--proxy--apt_flat)
* [`ensure`](#-nexus--resource--repository--apt--proxy--ensure)
* [`http_client_auto_block`](#-nexus--resource--repository--apt--proxy--http_client_auto_block)
* [`http_client_blocked`](#-nexus--resource--repository--apt--proxy--http_client_blocked)
* [`negative_cache_enabled`](#-nexus--resource--repository--apt--proxy--negative_cache_enabled)
* [`negative_cache_time_to_live`](#-nexus--resource--repository--apt--proxy--negative_cache_time_to_live)
* [`online`](#-nexus--resource--repository--apt--proxy--online)
* [`proxy_content_max_age`](#-nexus--resource--repository--apt--proxy--proxy_content_max_age)
* [`proxy_metadata_max_age`](#-nexus--resource--repository--apt--proxy--proxy_metadata_max_age)
* [`storage_blob_store_name`](#-nexus--resource--repository--apt--proxy--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--apt--proxy--storage_strict_content_type_validation)
* [`storage_write_policy`](#-nexus--resource--repository--apt--proxy--storage_write_policy)
* [`cleanup_policy_names`](#-nexus--resource--repository--apt--proxy--cleanup_policy_names)

##### <a name="-nexus--resource--repository--apt--proxy--apt_distribution"></a>`apt_distribution`

Data type: `String[1]`

APT distribution like buster, bullseye used by nexus repository manager to query the upstream repository.

##### <a name="-nexus--resource--repository--apt--proxy--proxy_remote_url"></a>`proxy_remote_url`

Data type: `Stdlib::HTTPUrl`

APT repository url like https://deb.debian.org/debian/.

##### <a name="-nexus--resource--repository--apt--proxy--apt_flat"></a>`apt_flat`

Data type: `Boolean`

Is the upstream repository flat format?

Default value: `false`

##### <a name="-nexus--resource--repository--apt--proxy--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--apt--proxy--http_client_auto_block"></a>`http_client_auto_block`

Data type: `Boolean`

Auto-block outbound connections on the repository if remote peer is detected as unreachable/unresponsive.

Default value: `true`

##### <a name="-nexus--resource--repository--apt--proxy--http_client_blocked"></a>`http_client_blocked`

Data type: `Boolean`

Block outbound connections on the repository.

Default value: `false`

##### <a name="-nexus--resource--repository--apt--proxy--negative_cache_enabled"></a>`negative_cache_enabled`

Data type: `Boolean`

Cache responses for content not present in the proxied repository.

Default value: `true`

##### <a name="-nexus--resource--repository--apt--proxy--negative_cache_time_to_live"></a>`negative_cache_time_to_live`

Data type: `Integer`

How long to cache the fact that a file was not found in the repository (in minutes).

Default value: `1440`

##### <a name="-nexus--resource--repository--apt--proxy--online"></a>`online`

Data type: `Boolean`

Enable this repository in nexus repository manager that it can be used.

Default value: `true`

##### <a name="-nexus--resource--repository--apt--proxy--proxy_content_max_age"></a>`proxy_content_max_age`

Data type: `Integer`

Max age of content (packages)

Default value: `1440`

##### <a name="-nexus--resource--repository--apt--proxy--proxy_metadata_max_age"></a>`proxy_metadata_max_age`

Data type: `Integer`

Max age of the repository metadata

Default value: `1440`

##### <a name="-nexus--resource--repository--apt--proxy--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--apt--proxy--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Validate that all content uploaded to this repository is of a MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--apt--proxy--storage_write_policy"></a>`storage_write_policy`

Data type: `Enum['ALLOW']`

Controls if deployments of and updates to artifacts are allowed.

Default value: `'ALLOW'`

##### <a name="-nexus--resource--repository--apt--proxy--cleanup_policy_names"></a>`cleanup_policy_names`

Data type: `Array[String[1]]`

Apply a list of cleanup policies to the repository. If a cleanup policy doesn't exist, nothing happens.

Default value: `[]`

### <a name="nexus--resource--repository--docker--group"></a>`nexus::resource::repository::docker::group`

Resource to manage docker group repository

#### Examples

##### 

```puppet
nexus::repository::docker::group { 'docker-group':
   group_member_names => [
      'docker-hosted',
      'docker-docker.io',
   ],
}
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::docker::group` defined type:

* [`ensure`](#-nexus--resource--repository--docker--group--ensure)
* [`online`](#-nexus--resource--repository--docker--group--online)
* [`storage_blob_store_name`](#-nexus--resource--repository--docker--group--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--docker--group--storage_strict_content_type_validation)
* [`group_member_names`](#-nexus--resource--repository--docker--group--group_member_names)
* [`docker_v1_enabled`](#-nexus--resource--repository--docker--group--docker_v1_enabled)
* [`docker_force_basic_auth`](#-nexus--resource--repository--docker--group--docker_force_basic_auth)
* [`docker_http_port`](#-nexus--resource--repository--docker--group--docker_http_port)
* [`docker_https_port`](#-nexus--resource--repository--docker--group--docker_https_port)
* [`docker_subdomain`](#-nexus--resource--repository--docker--group--docker_subdomain)

##### <a name="-nexus--resource--repository--docker--group--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--docker--group--online"></a>`online`

Data type: `Boolean`

Allow incoming requests to this repository.

Default value: `true`

##### <a name="-nexus--resource--repository--docker--group--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--docker--group--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Validate that all content uploaded to this repository is of a MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--docker--group--group_member_names"></a>`group_member_names`

Data type: `Array[String[1]]`

Ordered array of the (docker) member to be grouped into this repository.

Default value: `[]`

##### <a name="-nexus--resource--repository--docker--group--docker_v1_enabled"></a>`docker_v1_enabled`

Data type: `Boolean`

Allow clients to use the V1 API to interact with this repository.

Default value: `false`

##### <a name="-nexus--resource--repository--docker--group--docker_force_basic_auth"></a>`docker_force_basic_auth`

Data type: `Boolean`

Allow anonymous docker pull ( Docker Bearer Token Realm required ).

Default value: `true`

##### <a name="-nexus--resource--repository--docker--group--docker_http_port"></a>`docker_http_port`

Data type: `Optional[Stdlib::Port]`

Create an HTTP connector at specified port. Normally used if the server is behind a secure proxy.

Default value: `undef`

##### <a name="-nexus--resource--repository--docker--group--docker_https_port"></a>`docker_https_port`

Data type: `Optional[Stdlib::Port]`

Create an HTTPS connector at specified port. Normally used if the server is configured for https.

Default value: `undef`

##### <a name="-nexus--resource--repository--docker--group--docker_subdomain"></a>`docker_subdomain`

Data type: `Optional[Stdlib::Fqdn]`

Use the following subdomain to make push and pull requests for this repository.

Default value: `undef`

### <a name="nexus--resource--repository--docker--hosted"></a>`nexus::resource::repository::docker::hosted`

Resource to manage docker hosted repository

#### Examples

##### 

```puppet
nexus::repository::docker::hosted { 'docker-hosted':
}
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::docker::hosted` defined type:

* [`ensure`](#-nexus--resource--repository--docker--hosted--ensure)
* [`online`](#-nexus--resource--repository--docker--hosted--online)
* [`storage_blob_store_name`](#-nexus--resource--repository--docker--hosted--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--docker--hosted--storage_strict_content_type_validation)
* [`storage_write_policy`](#-nexus--resource--repository--docker--hosted--storage_write_policy)
* [`component_proprietary_components`](#-nexus--resource--repository--docker--hosted--component_proprietary_components)
* [`docker_v1_enabled`](#-nexus--resource--repository--docker--hosted--docker_v1_enabled)
* [`docker_force_basic_auth`](#-nexus--resource--repository--docker--hosted--docker_force_basic_auth)
* [`docker_http_port`](#-nexus--resource--repository--docker--hosted--docker_http_port)
* [`docker_https_port`](#-nexus--resource--repository--docker--hosted--docker_https_port)
* [`docker_subdomain`](#-nexus--resource--repository--docker--hosted--docker_subdomain)
* [`cleanup_policy_names`](#-nexus--resource--repository--docker--hosted--cleanup_policy_names)

##### <a name="-nexus--resource--repository--docker--hosted--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--docker--hosted--online"></a>`online`

Data type: `Boolean`

Allow incoming requests to this repository.

Default value: `true`

##### <a name="-nexus--resource--repository--docker--hosted--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--docker--hosted--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Validate that all content uploaded to this repository is of a MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--docker--hosted--storage_write_policy"></a>`storage_write_policy`

Data type: `Enum['ALLOW','ALLOW_ONCE','DENY']`

Controls if deployments of and updates to artifacts are allowed.

Default value: `'ALLOW_ONCE'`

##### <a name="-nexus--resource--repository--docker--hosted--component_proprietary_components"></a>`component_proprietary_components`

Data type: `Boolean`

Components in this repository count as proprietary for namespace conflict attacks (requires Sonatype Nexus Firewall).

Default value: `true`

##### <a name="-nexus--resource--repository--docker--hosted--docker_v1_enabled"></a>`docker_v1_enabled`

Data type: `Boolean`

Allow clients to use the V1 API to interact with this repository.

Default value: `false`

##### <a name="-nexus--resource--repository--docker--hosted--docker_force_basic_auth"></a>`docker_force_basic_auth`

Data type: `Boolean`

Allow anonymous docker pull ( Docker Bearer Token Realm required ).

Default value: `true`

##### <a name="-nexus--resource--repository--docker--hosted--docker_http_port"></a>`docker_http_port`

Data type: `Optional[Stdlib::Port]`

Create an HTTP connector at specified port. Normally used if the server is behind a secure proxy.

Default value: `undef`

##### <a name="-nexus--resource--repository--docker--hosted--docker_https_port"></a>`docker_https_port`

Data type: `Optional[Stdlib::Port]`

Create an HTTPS connector at specified port. Normally used if the server is configured for https.

Default value: `undef`

##### <a name="-nexus--resource--repository--docker--hosted--docker_subdomain"></a>`docker_subdomain`

Data type: `Optional[Stdlib::Fqdn]`

Use the following subdomain to make push and pull requests for this repository.

Default value: `undef`

##### <a name="-nexus--resource--repository--docker--hosted--cleanup_policy_names"></a>`cleanup_policy_names`

Data type: `Array[String[1]]`

Apply a list of cleanup policies to the repository. If a cleanup policy doesn't exist, nothing happens.

Default value: `[]`

### <a name="nexus--resource--repository--docker--proxy"></a>`nexus::resource::repository::docker::proxy`

Resource to manage docker proxy repository

#### Examples

##### 

```puppet
nexus::resource::repository::docker::proxy { 'docker-docker.io':
   proxy_remote_url => 'https://registry-1.docker.io',
}
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::docker::proxy` defined type:

* [`proxy_remote_url`](#-nexus--resource--repository--docker--proxy--proxy_remote_url)
* [`ensure`](#-nexus--resource--repository--docker--proxy--ensure)
* [`http_client_auto_block`](#-nexus--resource--repository--docker--proxy--http_client_auto_block)
* [`http_client_blocked`](#-nexus--resource--repository--docker--proxy--http_client_blocked)
* [`authentication`](#-nexus--resource--repository--docker--proxy--authentication)
* [`negative_cache_enabled`](#-nexus--resource--repository--docker--proxy--negative_cache_enabled)
* [`negative_cache_time_to_live`](#-nexus--resource--repository--docker--proxy--negative_cache_time_to_live)
* [`online`](#-nexus--resource--repository--docker--proxy--online)
* [`proxy_content_max_age`](#-nexus--resource--repository--docker--proxy--proxy_content_max_age)
* [`proxy_metadata_max_age`](#-nexus--resource--repository--docker--proxy--proxy_metadata_max_age)
* [`storage_blob_store_name`](#-nexus--resource--repository--docker--proxy--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--docker--proxy--storage_strict_content_type_validation)
* [`storage_write_policy`](#-nexus--resource--repository--docker--proxy--storage_write_policy)
* [`docker_v1_enabled`](#-nexus--resource--repository--docker--proxy--docker_v1_enabled)
* [`docker_force_basic_auth`](#-nexus--resource--repository--docker--proxy--docker_force_basic_auth)
* [`docker_http_port`](#-nexus--resource--repository--docker--proxy--docker_http_port)
* [`docker_https_port`](#-nexus--resource--repository--docker--proxy--docker_https_port)
* [`docker_subdomain`](#-nexus--resource--repository--docker--proxy--docker_subdomain)
* [`docker_proxy_index_type`](#-nexus--resource--repository--docker--proxy--docker_proxy_index_type)
* [`docker_proxy_index_url`](#-nexus--resource--repository--docker--proxy--docker_proxy_index_url)
* [`docker_proxy_cache_foreign_layers`](#-nexus--resource--repository--docker--proxy--docker_proxy_cache_foreign_layers)
* [`docker_proxy_foreign_layer_url_whitelist`](#-nexus--resource--repository--docker--proxy--docker_proxy_foreign_layer_url_whitelist)
* [`cleanup_policy_names`](#-nexus--resource--repository--docker--proxy--cleanup_policy_names)

##### <a name="-nexus--resource--repository--docker--proxy--proxy_remote_url"></a>`proxy_remote_url`

Data type: `Stdlib::HTTPSUrl`

Docker repository url like https://registry-1.docker.io.

##### <a name="-nexus--resource--repository--docker--proxy--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--docker--proxy--http_client_auto_block"></a>`http_client_auto_block`

Data type: `Boolean`

Auto-block outbound connections on the repository if remote peer is detected as unreachable/unresponsive.

Default value: `true`

##### <a name="-nexus--resource--repository--docker--proxy--http_client_blocked"></a>`http_client_blocked`

Data type: `Boolean`

Block outbound connections on the repository.

Default value: `false`

##### <a name="-nexus--resource--repository--docker--proxy--authentication"></a>`authentication`

Data type:

```puppet
Optional[Struct[{
        type => Enum['username', 'ntlm'],
        username => String[1],
        password => String[1],
        Optional[ntlmHost] => Optional[String[1]],
        Optional[ntlmDomain] => Optional[String[1]],
  }]]
```



Default value: `undef`

##### <a name="-nexus--resource--repository--docker--proxy--negative_cache_enabled"></a>`negative_cache_enabled`

Data type: `Boolean`

Cache responses for content not present in the proxied repository.

Default value: `true`

##### <a name="-nexus--resource--repository--docker--proxy--negative_cache_time_to_live"></a>`negative_cache_time_to_live`

Data type: `Integer`

How long to cache the fact that a file was not found in the repository (in minutes).

Default value: `1440`

##### <a name="-nexus--resource--repository--docker--proxy--online"></a>`online`

Data type: `Boolean`

Enable this repository in nexus repository manager that it can be used.

Default value: `true`

##### <a name="-nexus--resource--repository--docker--proxy--proxy_content_max_age"></a>`proxy_content_max_age`

Data type: `Integer`

Max age of content (packages).

Default value: `1440`

##### <a name="-nexus--resource--repository--docker--proxy--proxy_metadata_max_age"></a>`proxy_metadata_max_age`

Data type: `Integer`

Max age of the repository metadata.

Default value: `1440`

##### <a name="-nexus--resource--repository--docker--proxy--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--docker--proxy--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Validate that all content uploaded to this repository is of a MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--docker--proxy--storage_write_policy"></a>`storage_write_policy`

Data type: `Enum['ALLOW','ALLOW_ONCE','DENY']`

Controls if deployments of and updates to artifacts are allowed.

Default value: `'ALLOW'`

##### <a name="-nexus--resource--repository--docker--proxy--docker_v1_enabled"></a>`docker_v1_enabled`

Data type: `Boolean`

Allow clients to use the V1 API to interact with this repository.

Default value: `false`

##### <a name="-nexus--resource--repository--docker--proxy--docker_force_basic_auth"></a>`docker_force_basic_auth`

Data type: `Boolean`

Allow anonymous docker pull ( Docker Bearer Token Realm required ).

Default value: `true`

##### <a name="-nexus--resource--repository--docker--proxy--docker_http_port"></a>`docker_http_port`

Data type: `Optional[Stdlib::Port]`

Create an HTTP connector at specified port. Normally used if the server is behind a secure proxy.

Default value: `undef`

##### <a name="-nexus--resource--repository--docker--proxy--docker_https_port"></a>`docker_https_port`

Data type: `Optional[Stdlib::Port]`

Create an HTTPS connector at specified port. Normally used if the server is configured for https.

Default value: `undef`

##### <a name="-nexus--resource--repository--docker--proxy--docker_subdomain"></a>`docker_subdomain`

Data type: `Optional[Stdlib::Fqdn]`

Use the following subdomain to make push and pull requests for this repository.

Default value: `undef`

##### <a name="-nexus--resource--repository--docker--proxy--docker_proxy_index_type"></a>`docker_proxy_index_type`

Data type: `Enum['REGISTRY','HUB','CUSTOM']`

Docker index type. See https://help.sonatype.com/repomanager3/nexus-repository-administration/formats/docker-registry/proxy-repository-for-docker#ProxyRepositoryforDocker-ConfiguringaCorrectRemoteStorageandDockerIndexURLPair

Default value: `'HUB'`

##### <a name="-nexus--resource--repository--docker--proxy--docker_proxy_index_url"></a>`docker_proxy_index_url`

Data type: `Optional[Stdlib::HTTPSUrl]`

If docker_proxy_index_type is CUSTOM you have to set the uri of the index api.

Default value: `undef`

##### <a name="-nexus--resource--repository--docker--proxy--docker_proxy_cache_foreign_layers"></a>`docker_proxy_cache_foreign_layers`

Data type: `Boolean`

Allow Nexus Repository Manager to download and cache foreign layers.

Default value: `false`

##### <a name="-nexus--resource--repository--docker--proxy--docker_proxy_foreign_layer_url_whitelist"></a>`docker_proxy_foreign_layer_url_whitelist`

Data type: `Array[String[1]]`

Regular expressions used to identify URLs that are allowed for foreign layer requests.

Default value: `[]`

##### <a name="-nexus--resource--repository--docker--proxy--cleanup_policy_names"></a>`cleanup_policy_names`

Data type: `Array[String[1]]`

Apply a list of cleanup policies to the repository. If a cleanup policy doesn't exist, nothing happens.

Default value: `[]`

### <a name="nexus--resource--repository--npm--group"></a>`nexus::resource::repository::npm::group`

Resource to manage npm group repository

#### Examples

##### 

```puppet
nexus::repository::npm::group { 'npm-group':
   group_member_names => [
      'npm-hosted',
      'npm-npmjs.org',
   ],
}
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::npm::group` defined type:

* [`ensure`](#-nexus--resource--repository--npm--group--ensure)
* [`online`](#-nexus--resource--repository--npm--group--online)
* [`storage_blob_store_name`](#-nexus--resource--repository--npm--group--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--npm--group--storage_strict_content_type_validation)
* [`group_member_names`](#-nexus--resource--repository--npm--group--group_member_names)

##### <a name="-nexus--resource--repository--npm--group--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--npm--group--online"></a>`online`

Data type: `Boolean`

Enable this repository in nexus repository manager that it can be used.

Default value: `true`

##### <a name="-nexus--resource--repository--npm--group--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--npm--group--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Validate that all content uploaded to this repository is of a MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--npm--group--group_member_names"></a>`group_member_names`

Data type: `Array[String[1]]`

Ordered array of the (npm) member to be grouped into this repository.

Default value: `[]`

### <a name="nexus--resource--repository--npm--hosted"></a>`nexus::resource::repository::npm::hosted`

Resource to manage npm hosted repository

#### Examples

##### 

```puppet
nexus::resource::repository::npm::hosted { 'npm-hosted': }
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::npm::hosted` defined type:

* [`ensure`](#-nexus--resource--repository--npm--hosted--ensure)
* [`online`](#-nexus--resource--repository--npm--hosted--online)
* [`storage_blob_store_name`](#-nexus--resource--repository--npm--hosted--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--npm--hosted--storage_strict_content_type_validation)
* [`storage_write_policy`](#-nexus--resource--repository--npm--hosted--storage_write_policy)
* [`component_proprietary_components`](#-nexus--resource--repository--npm--hosted--component_proprietary_components)
* [`cleanup_policy_names`](#-nexus--resource--repository--npm--hosted--cleanup_policy_names)

##### <a name="-nexus--resource--repository--npm--hosted--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--npm--hosted--online"></a>`online`

Data type: `Boolean`

Enable this repository in nexus repository manager that it can be used.

Default value: `true`

##### <a name="-nexus--resource--repository--npm--hosted--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--npm--hosted--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Validate that all content uploaded to this repository is of a MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--npm--hosted--storage_write_policy"></a>`storage_write_policy`

Data type: `Enum['allow', 'allow_once', 'deny']`

Controls if deployments of and updates to artifacts are allowed.

Default value: `'allow_once'`

##### <a name="-nexus--resource--repository--npm--hosted--component_proprietary_components"></a>`component_proprietary_components`

Data type: `Boolean`

Components in this repository count as proprietary for namespace conflict attacks (requires Sonatype Nexus Firewall).

Default value: `true`

##### <a name="-nexus--resource--repository--npm--hosted--cleanup_policy_names"></a>`cleanup_policy_names`

Data type: `Array[String[1]]`

Apply a list of cleanup policies to the repository. If a cleanup policy doesn't exist, nothing happens.

Default value: `[]`

### <a name="nexus--resource--repository--npm--proxy"></a>`nexus::resource::repository::npm::proxy`

Resource to manage npm proxy repository

#### Examples

##### 

```puppet
nexus::repository::npm::proxy { 'npm-npmjs.org':
   proxy_remote_url => 'https://registry.npmjs.org',
}
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::npm::proxy` defined type:

* [`proxy_remote_url`](#-nexus--resource--repository--npm--proxy--proxy_remote_url)
* [`ensure`](#-nexus--resource--repository--npm--proxy--ensure)
* [`npm_remove_non_cataloged`](#-nexus--resource--repository--npm--proxy--npm_remove_non_cataloged)
* [`npm_remove_quarantined`](#-nexus--resource--repository--npm--proxy--npm_remove_quarantined)
* [`http_client_auto_block`](#-nexus--resource--repository--npm--proxy--http_client_auto_block)
* [`http_client_blocked`](#-nexus--resource--repository--npm--proxy--http_client_blocked)
* [`negative_cache_enabled`](#-nexus--resource--repository--npm--proxy--negative_cache_enabled)
* [`negative_cache_time_to_live`](#-nexus--resource--repository--npm--proxy--negative_cache_time_to_live)
* [`online`](#-nexus--resource--repository--npm--proxy--online)
* [`proxy_content_max_age`](#-nexus--resource--repository--npm--proxy--proxy_content_max_age)
* [`proxy_metadata_max_age`](#-nexus--resource--repository--npm--proxy--proxy_metadata_max_age)
* [`storage_blob_store_name`](#-nexus--resource--repository--npm--proxy--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--npm--proxy--storage_strict_content_type_validation)
* [`storage_write_policy`](#-nexus--resource--repository--npm--proxy--storage_write_policy)
* [`cleanup_policy_names`](#-nexus--resource--repository--npm--proxy--cleanup_policy_names)

##### <a name="-nexus--resource--repository--npm--proxy--proxy_remote_url"></a>`proxy_remote_url`

Data type: `Stdlib::HTTPSUrl`

NPM repository url like https://registry.npmjs.org.

##### <a name="-nexus--resource--repository--npm--proxy--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--npm--proxy--npm_remove_non_cataloged"></a>`npm_remove_non_cataloged`

Data type: `Boolean`

Remove non-cataloged versions from the npm package metadata. (Requires IQ: Audit and Quarantine)

Default value: `false`

##### <a name="-nexus--resource--repository--npm--proxy--npm_remove_quarantined"></a>`npm_remove_quarantined`

Data type: `Boolean`

Remove quarantined versions from the npm package metadata. (Requires IQ: Audit and Quarantine)

Default value: `false`

##### <a name="-nexus--resource--repository--npm--proxy--http_client_auto_block"></a>`http_client_auto_block`

Data type: `Boolean`

Auto-block outbound connections on the repository if remote peer is detected as unreachable/unresponsive.

Default value: `true`

##### <a name="-nexus--resource--repository--npm--proxy--http_client_blocked"></a>`http_client_blocked`

Data type: `Boolean`

Block outbound connections on the repository.

Default value: `false`

##### <a name="-nexus--resource--repository--npm--proxy--negative_cache_enabled"></a>`negative_cache_enabled`

Data type: `Boolean`

Cache responses for content not present in the proxied repository.

Default value: `true`

##### <a name="-nexus--resource--repository--npm--proxy--negative_cache_time_to_live"></a>`negative_cache_time_to_live`

Data type: `Integer`

How long to cache the fact that a file was not found in the repository (in minutes).

Default value: `1440`

##### <a name="-nexus--resource--repository--npm--proxy--online"></a>`online`

Data type: `Boolean`

Enable this repository in nexus repository manager that it can be used.

Default value: `true`

##### <a name="-nexus--resource--repository--npm--proxy--proxy_content_max_age"></a>`proxy_content_max_age`

Data type: `Integer`

Max age of content (packages).

Default value: `1440`

##### <a name="-nexus--resource--repository--npm--proxy--proxy_metadata_max_age"></a>`proxy_metadata_max_age`

Data type: `Integer`

Max age of the repository metadata.

Default value: `1440`

##### <a name="-nexus--resource--repository--npm--proxy--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--npm--proxy--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Validate that all content uploaded to this repository is of a MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--npm--proxy--storage_write_policy"></a>`storage_write_policy`

Data type: `Enum['ALLOW','ALLOW_ONCE','DENY']`

Controls if deployments of and updates to artifacts are allowed.

Default value: `'ALLOW'`

##### <a name="-nexus--resource--repository--npm--proxy--cleanup_policy_names"></a>`cleanup_policy_names`

Data type: `Array[String[1]]`

Apply a list of cleanup policies to the repository. If a cleanup policy doesn't exist, nothing happens.

Default value: `[]`

### <a name="nexus--resource--repository--pypi--proxy"></a>`nexus::resource::repository::pypi::proxy`

Resource to manage PyPi proxy repository

#### Examples

##### 

```puppet
nexus::resource::repository::pypi::proxy { 'pypi.org':
   proxy_remote_url => 'https://pypi.org',
}
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::pypi::proxy` defined type:

* [`proxy_remote_url`](#-nexus--resource--repository--pypi--proxy--proxy_remote_url)
* [`ensure`](#-nexus--resource--repository--pypi--proxy--ensure)
* [`http_client_auto_block`](#-nexus--resource--repository--pypi--proxy--http_client_auto_block)
* [`http_client_blocked`](#-nexus--resource--repository--pypi--proxy--http_client_blocked)
* [`negative_cache_enabled`](#-nexus--resource--repository--pypi--proxy--negative_cache_enabled)
* [`negative_cache_time_to_live`](#-nexus--resource--repository--pypi--proxy--negative_cache_time_to_live)
* [`online`](#-nexus--resource--repository--pypi--proxy--online)
* [`proxy_content_max_age`](#-nexus--resource--repository--pypi--proxy--proxy_content_max_age)
* [`proxy_metadata_max_age`](#-nexus--resource--repository--pypi--proxy--proxy_metadata_max_age)
* [`storage_blob_store_name`](#-nexus--resource--repository--pypi--proxy--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--pypi--proxy--storage_strict_content_type_validation)
* [`storage_write_policy`](#-nexus--resource--repository--pypi--proxy--storage_write_policy)
* [`remove_quarantined`](#-nexus--resource--repository--pypi--proxy--remove_quarantined)
* [`cleanup_policy_names`](#-nexus--resource--repository--pypi--proxy--cleanup_policy_names)

##### <a name="-nexus--resource--repository--pypi--proxy--proxy_remote_url"></a>`proxy_remote_url`

Data type: `Stdlib::HTTPSUrl`

PyPi repository url like https://pypi.org.

##### <a name="-nexus--resource--repository--pypi--proxy--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--pypi--proxy--http_client_auto_block"></a>`http_client_auto_block`

Data type: `Boolean`

Auto-block outbound connections on the repository if remote peer is detected as unreachable/unresponsive.

Default value: `true`

##### <a name="-nexus--resource--repository--pypi--proxy--http_client_blocked"></a>`http_client_blocked`

Data type: `Boolean`

Block outbound connections on the repository.

Default value: `false`

##### <a name="-nexus--resource--repository--pypi--proxy--negative_cache_enabled"></a>`negative_cache_enabled`

Data type: `Boolean`

Cache responses for content not present in the proxied repository.

Default value: `true`

##### <a name="-nexus--resource--repository--pypi--proxy--negative_cache_time_to_live"></a>`negative_cache_time_to_live`

Data type: `Integer`

How long to cache the fact that a file was not found in the repository (in minutes).

Default value: `1440`

##### <a name="-nexus--resource--repository--pypi--proxy--online"></a>`online`

Data type: `Boolean`

Enable this repository in nexus repository manager that it can be used.

Default value: `true`

##### <a name="-nexus--resource--repository--pypi--proxy--proxy_content_max_age"></a>`proxy_content_max_age`

Data type: `Integer`

Max age of content (packages).

Default value: `1440`

##### <a name="-nexus--resource--repository--pypi--proxy--proxy_metadata_max_age"></a>`proxy_metadata_max_age`

Data type: `Integer`

Max age of the repository metadata.

Default value: `1440`

##### <a name="-nexus--resource--repository--pypi--proxy--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--pypi--proxy--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Validate that all content uploaded to this repository is of a MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--pypi--proxy--storage_write_policy"></a>`storage_write_policy`

Data type: `Enum['ALLOW','ALLOW_ONCE','DENY']`

Controls if deployments of and updates to artifacts are allowed.

Default value: `'ALLOW'`

##### <a name="-nexus--resource--repository--pypi--proxy--remove_quarantined"></a>`remove_quarantined`

Data type: `Boolean`

Remove Quarantined Versions.

Default value: `false`

##### <a name="-nexus--resource--repository--pypi--proxy--cleanup_policy_names"></a>`cleanup_policy_names`

Data type: `Array[String[1]]`

Apply a list of cleanup policies to the repository. If a cleanup policy doesn't exist, nothing happens.

Default value: `[]`

### <a name="nexus--resource--repository--raw--hosted"></a>`nexus::resource::repository::raw::hosted`

Resource to manage raw hosted repository

#### Examples

##### 

```puppet
nexus::resource::repository::raw::hosted { 'raw-hosted': }
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::raw::hosted` defined type:

* [`ensure`](#-nexus--resource--repository--raw--hosted--ensure)
* [`online`](#-nexus--resource--repository--raw--hosted--online)
* [`storage_blob_store_name`](#-nexus--resource--repository--raw--hosted--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--raw--hosted--storage_strict_content_type_validation)
* [`storage_write_policy`](#-nexus--resource--repository--raw--hosted--storage_write_policy)
* [`component_proprietary_components`](#-nexus--resource--repository--raw--hosted--component_proprietary_components)
* [`content_disposition`](#-nexus--resource--repository--raw--hosted--content_disposition)
* [`cleanup_policy_names`](#-nexus--resource--repository--raw--hosted--cleanup_policy_names)

##### <a name="-nexus--resource--repository--raw--hosted--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--raw--hosted--online"></a>`online`

Data type: `Boolean`

Whether this repository accepts incoming requests.

Default value: `true`

##### <a name="-nexus--resource--repository--raw--hosted--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--raw--hosted--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Whether to validate uploaded content's MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--raw--hosted--storage_write_policy"></a>`storage_write_policy`

Data type: `Enum['allow', 'allow_once', 'deny']`

Controls if deployments of and updates to assets are allowed.

Default value: `'allow_once'`

##### <a name="-nexus--resource--repository--raw--hosted--component_proprietary_components"></a>`component_proprietary_components`

Data type: `Boolean`

Components in this repository count as proprietary for namespace conflict attacks (requires Sonatype Nexus Firewall).

Default value: `true`

##### <a name="-nexus--resource--repository--raw--hosted--content_disposition"></a>`content_disposition`

Data type: `Enum['INLINE', 'ATTACHMENT']`

Content Disposition

Default value: `'ATTACHMENT'`

##### <a name="-nexus--resource--repository--raw--hosted--cleanup_policy_names"></a>`cleanup_policy_names`

Data type: `Array[String[1]]`

Apply a list of cleanup policies to the repository. If a cleanup policy doesn't exist, nothing happens.

Default value: `[]`

### <a name="nexus--resource--repository--rubygems--proxy"></a>`nexus::resource::repository::rubygems::proxy`

Resource to manage RubyGems proxy repository

#### Examples

##### 

```puppet
nexus::resource::repository::rubygems::proxy { 'rubygems.org':
   proxy_remote_url => 'https://rubygems.org/',
}
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::rubygems::proxy` defined type:

* [`proxy_remote_url`](#-nexus--resource--repository--rubygems--proxy--proxy_remote_url)
* [`ensure`](#-nexus--resource--repository--rubygems--proxy--ensure)
* [`http_client_auto_block`](#-nexus--resource--repository--rubygems--proxy--http_client_auto_block)
* [`http_client_blocked`](#-nexus--resource--repository--rubygems--proxy--http_client_blocked)
* [`negative_cache_enabled`](#-nexus--resource--repository--rubygems--proxy--negative_cache_enabled)
* [`negative_cache_time_to_live`](#-nexus--resource--repository--rubygems--proxy--negative_cache_time_to_live)
* [`online`](#-nexus--resource--repository--rubygems--proxy--online)
* [`proxy_content_max_age`](#-nexus--resource--repository--rubygems--proxy--proxy_content_max_age)
* [`proxy_metadata_max_age`](#-nexus--resource--repository--rubygems--proxy--proxy_metadata_max_age)
* [`storage_blob_store_name`](#-nexus--resource--repository--rubygems--proxy--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--rubygems--proxy--storage_strict_content_type_validation)
* [`storage_write_policy`](#-nexus--resource--repository--rubygems--proxy--storage_write_policy)
* [`cleanup_policy_names`](#-nexus--resource--repository--rubygems--proxy--cleanup_policy_names)

##### <a name="-nexus--resource--repository--rubygems--proxy--proxy_remote_url"></a>`proxy_remote_url`

Data type: `Stdlib::HTTPSUrl`

RubyGems repository url like https://rubygems.org/.

##### <a name="-nexus--resource--repository--rubygems--proxy--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--rubygems--proxy--http_client_auto_block"></a>`http_client_auto_block`

Data type: `Boolean`

Auto-block outbound connections on the repository if remote peer is detected as unreachable/unresponsive.

Default value: `true`

##### <a name="-nexus--resource--repository--rubygems--proxy--http_client_blocked"></a>`http_client_blocked`

Data type: `Boolean`

Block outbound connections on the repository.

Default value: `false`

##### <a name="-nexus--resource--repository--rubygems--proxy--negative_cache_enabled"></a>`negative_cache_enabled`

Data type: `Boolean`

Cache responses for content not present in the proxied repository.

Default value: `true`

##### <a name="-nexus--resource--repository--rubygems--proxy--negative_cache_time_to_live"></a>`negative_cache_time_to_live`

Data type: `Integer`

How long to cache the fact that a file was not found in the repository (in minutes).

Default value: `1440`

##### <a name="-nexus--resource--repository--rubygems--proxy--online"></a>`online`

Data type: `Boolean`

Enable this repository in nexus repository manager that it can be used.

Default value: `true`

##### <a name="-nexus--resource--repository--rubygems--proxy--proxy_content_max_age"></a>`proxy_content_max_age`

Data type: `Integer`

Max age of content (packages).

Default value: `1440`

##### <a name="-nexus--resource--repository--rubygems--proxy--proxy_metadata_max_age"></a>`proxy_metadata_max_age`

Data type: `Integer`

Max age of the repository metadata.

Default value: `1440`

##### <a name="-nexus--resource--repository--rubygems--proxy--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--rubygems--proxy--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Validate that all content uploaded to this repository is of a MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--rubygems--proxy--storage_write_policy"></a>`storage_write_policy`

Data type: `Enum['ALLOW','ALLOW_ONCE','DENY']`

Controls if deployments of and updates to artifacts are allowed.

Default value: `'ALLOW'`

##### <a name="-nexus--resource--repository--rubygems--proxy--cleanup_policy_names"></a>`cleanup_policy_names`

Data type: `Array[String[1]]`

Apply a list of cleanup policies to the repository. If a cleanup policy doesn't exist, nothing happens.

Default value: `[]`

### <a name="nexus--resource--repository--yum--hosted"></a>`nexus::resource::repository::yum::hosted`

Resource to manage yum hosted repository

#### Examples

##### 

```puppet
nexus::resource::repository::yum::hosted { 'yum-hosted':
  repodata_depth => 5,
}
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::yum::hosted` defined type:

* [`ensure`](#-nexus--resource--repository--yum--hosted--ensure)
* [`online`](#-nexus--resource--repository--yum--hosted--online)
* [`storage_blob_store_name`](#-nexus--resource--repository--yum--hosted--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--yum--hosted--storage_strict_content_type_validation)
* [`storage_write_policy`](#-nexus--resource--repository--yum--hosted--storage_write_policy)
* [`component_proprietary_components`](#-nexus--resource--repository--yum--hosted--component_proprietary_components)
* [`repodata_depth`](#-nexus--resource--repository--yum--hosted--repodata_depth)
* [`deploy_policy`](#-nexus--resource--repository--yum--hosted--deploy_policy)
* [`cleanup_policy_names`](#-nexus--resource--repository--yum--hosted--cleanup_policy_names)

##### <a name="-nexus--resource--repository--yum--hosted--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--yum--hosted--online"></a>`online`

Data type: `Boolean`

Allow incoming requests to this repository.

Default value: `true`

##### <a name="-nexus--resource--repository--yum--hosted--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--yum--hosted--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Validate that all content uploaded to this repository is of a MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--yum--hosted--storage_write_policy"></a>`storage_write_policy`

Data type: `Enum['ALLOW','ALLOW_ONCE','DENY']`

Controls if deployments of and updates to artifacts are allowed.

Default value: `'ALLOW_ONCE'`

##### <a name="-nexus--resource--repository--yum--hosted--component_proprietary_components"></a>`component_proprietary_components`

Data type: `Boolean`

Components in this repository count as proprietary for namespace conflict attacks (requires Sonatype Nexus Firewall).

Default value: `true`

##### <a name="-nexus--resource--repository--yum--hosted--repodata_depth"></a>`repodata_depth`

Data type: `Integer[0, 5]`

Set the depth of the directory in which the repodata/repomd.xml will be generated.

Default value: `0`

##### <a name="-nexus--resource--repository--yum--hosted--deploy_policy"></a>`deploy_policy`

Data type: `Enum['STRICT','PERMISSIVE']`

Set the deploy policy, whether or not a redeploy of rpm's is allowed.

Default value: `'STRICT'`

##### <a name="-nexus--resource--repository--yum--hosted--cleanup_policy_names"></a>`cleanup_policy_names`

Data type: `Array[String[1]]`

Apply a list of cleanup policies to the repository. If a cleanup policy doesn't exist, nothing happens.

Default value: `[]`

### <a name="nexus--resource--repository--yum--proxy"></a>`nexus::resource::repository::yum::proxy`

Resource to manage yum proxy repository

#### Examples

##### 

```puppet
nexus::resource::repository::yum::proxy { 'yum-oracle-latest':
   proxy_remote_url => 'https://yum.oracle.com/repo/OracleLinux/OL7/latest/x86_64/',
}
```

#### Parameters

The following parameters are available in the `nexus::resource::repository::yum::proxy` defined type:

* [`proxy_remote_url`](#-nexus--resource--repository--yum--proxy--proxy_remote_url)
* [`ensure`](#-nexus--resource--repository--yum--proxy--ensure)
* [`http_client_auto_block`](#-nexus--resource--repository--yum--proxy--http_client_auto_block)
* [`http_client_blocked`](#-nexus--resource--repository--yum--proxy--http_client_blocked)
* [`negative_cache_enabled`](#-nexus--resource--repository--yum--proxy--negative_cache_enabled)
* [`negative_cache_time_to_live`](#-nexus--resource--repository--yum--proxy--negative_cache_time_to_live)
* [`online`](#-nexus--resource--repository--yum--proxy--online)
* [`proxy_content_max_age`](#-nexus--resource--repository--yum--proxy--proxy_content_max_age)
* [`proxy_metadata_max_age`](#-nexus--resource--repository--yum--proxy--proxy_metadata_max_age)
* [`storage_blob_store_name`](#-nexus--resource--repository--yum--proxy--storage_blob_store_name)
* [`storage_strict_content_type_validation`](#-nexus--resource--repository--yum--proxy--storage_strict_content_type_validation)
* [`storage_write_policy`](#-nexus--resource--repository--yum--proxy--storage_write_policy)
* [`cleanup_policy_names`](#-nexus--resource--repository--yum--proxy--cleanup_policy_names)

##### <a name="-nexus--resource--repository--yum--proxy--proxy_remote_url"></a>`proxy_remote_url`

Data type: `Stdlib::HTTPSUrl`

yum repository url like https://yum.oracle.com/repo/OracleLinux/OL7/latest/x86_64/.

##### <a name="-nexus--resource--repository--yum--proxy--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Define if the resource should be created/present or deleted/absent.

Default value: `'present'`

##### <a name="-nexus--resource--repository--yum--proxy--http_client_auto_block"></a>`http_client_auto_block`

Data type: `Boolean`

Auto-block outbound connections on the repository if remote peer is detected as unreachable/unresponsive.

Default value: `true`

##### <a name="-nexus--resource--repository--yum--proxy--http_client_blocked"></a>`http_client_blocked`

Data type: `Boolean`

Block outbound connections on the repository.

Default value: `false`

##### <a name="-nexus--resource--repository--yum--proxy--negative_cache_enabled"></a>`negative_cache_enabled`

Data type: `Boolean`

Cache responses for content not present in the proxied repository.

Default value: `true`

##### <a name="-nexus--resource--repository--yum--proxy--negative_cache_time_to_live"></a>`negative_cache_time_to_live`

Data type: `Integer`

How long to cache the fact that a file was not found in the repository (in minutes).

Default value: `1440`

##### <a name="-nexus--resource--repository--yum--proxy--online"></a>`online`

Data type: `Boolean`

Enable this repository in nexus repository manager that it can be used.

Default value: `true`

##### <a name="-nexus--resource--repository--yum--proxy--proxy_content_max_age"></a>`proxy_content_max_age`

Data type: `Integer`

Max age of content (packages)

Default value: `1440`

##### <a name="-nexus--resource--repository--yum--proxy--proxy_metadata_max_age"></a>`proxy_metadata_max_age`

Data type: `Integer`

Max age of the repository metadata

Default value: `1440`

##### <a name="-nexus--resource--repository--yum--proxy--storage_blob_store_name"></a>`storage_blob_store_name`

Data type: `String[1]`

The name of the blobstore inside of nexus repository manager to be used. We suggest to use a own blobstore for each
defined repository.

Default value: `$title`

##### <a name="-nexus--resource--repository--yum--proxy--storage_strict_content_type_validation"></a>`storage_strict_content_type_validation`

Data type: `Boolean`

Validate that all content uploaded to this repository is of a MIME type appropriate for the repository format.

Default value: `true`

##### <a name="-nexus--resource--repository--yum--proxy--storage_write_policy"></a>`storage_write_policy`

Data type: `Enum['ALLOW']`

Controls if deployments of and updates to artifacts are allowed.

Default value: `'ALLOW'`

##### <a name="-nexus--resource--repository--yum--proxy--cleanup_policy_names"></a>`cleanup_policy_names`

Data type: `Array[String[1]]`

Apply a list of cleanup policies to the repository. If a cleanup policy doesn't exist, nothing happens.

Default value: `[]`

## Resource types

### <a name="nexus_blobstore"></a>`nexus_blobstore`

Raw provider to configure blobstore over the nexus repository manager rest api.

Please use the defined types instead of this one directly.

#### Properties

The following properties are available in the `nexus_blobstore` type.

##### `attributes`

Data type: `Hash`

The config settings of this blobstore definition.

##### `ensure`

Data type: `Enum[present, absent]`

Whether this resource should be present or absent on the target system.

Default value: `present`

##### `type`

Data type: `Enum[azure, file, s3]`

Blobstore type.

#### Parameters

The following parameters are available in the `nexus_blobstore` type.

* [`name`](#-nexus_blobstore--name)

##### <a name="-nexus_blobstore--name"></a>`name`

namevar

Data type: `String`

The name of the resource you want to manage.

### <a name="nexus_repository"></a>`nexus_repository`

Raw provider to configure repository over the nexus repository manager rest api.

Please use the defined types instead of this one directly.

#### Properties

The following properties are available in the `nexus_repository` type.

##### `attributes`

Data type: `Hash`

The config settings of this repository definition.

##### `ensure`

Data type: `Enum[present, absent]`

Whether this resource should be present or absent on the target system.

Default value: `present`

##### `format`

Data type: `String`

The format of the resource you want to manage

##### `type`

Data type: `Enum[group, hosted, proxy]`

Repository type.

#### Parameters

The following parameters are available in the `nexus_repository` type.

* [`name`](#-nexus_repository--name)

##### <a name="-nexus_repository--name"></a>`name`

namevar

Data type: `String`

The name of the resource you want to manage.

### <a name="nexus_role"></a>`nexus_role`

```puppet
nexus_role { 'rolename':
  ensure      => 'present',
  id          => 'reader',
  description => 'read access to raw repository',
  privileges  => ['nx-repository-view-raw-*-read'],
  roles       => '',
}
```

#### Properties

The following properties are available in the `nexus_role` type.

##### `description`

Data type: `Optional[String]`

The description of the role.

##### `ensure`

Data type: `Enum[present, absent]`

Whether this resource should be present or absent on the target system.

Default value: `present`

##### `name`

Data type: `Optional[String]`

The name of the role which will be the same like id.

##### `privileges`

Data type: `Optional[Array[String]]`

The privileges the role should have

##### `read_only`

Data type: `Optional[Boolean]`

Define as read only.

##### `roles`

Data type: `Optional[Array[String]]`

Other roles the new role should have

##### `source`

Data type: `Optional[String]`

The source of the role. Like local or LDAP

#### Parameters

The following parameters are available in the `nexus_role` type.

* [`id`](#-nexus_role--id)

##### <a name="-nexus_role--id"></a>`id`

namevar

Data type: `String`

The id of the role

### <a name="nexus_setting"></a>`nexus_setting`

Raw provider to set settings over the nexus repository manager rest api.

Please use nexus::config::* classes instead of this one directly.

#### Properties

The following properties are available in the `nexus_setting` type.

##### `attributes`

Data type: `Hash`

The config settings returned from the given api endpoint.

##### `ensure`

Data type: `Enum[present, absent]`

Whether this resource should be present or absent on the target system.

Default value: `present`

#### Parameters

The following parameters are available in the `nexus_setting` type.

* [`name`](#-nexus_setting--name)

##### <a name="-nexus_setting--name"></a>`name`

namevar

Data type: `String`

The api endpoint of simple nexus config settings.

### <a name="nexus_user"></a>`nexus_user`

```puppet
nexus_user { 'user.name':
  ensure        => 'present',
  user_id       => 'user.name',
  password      => 'hunter2',
  first_name    => 'Foo',
  last_name     => 'Bar',
  email_address => 'foo.bar@example.org',
  status        => 'active',
  roles         => ['nx-admin'],
}
```

#### Properties

The following properties are available in the `nexus_user` type.

##### `email_address`

Data type: `String`

The email address of the user.

##### `ensure`

Data type: `Enum[present, absent]`

Whether this resource should be present or absent on the target system.

Default value: `present`

##### `external_roles`

Data type: `Optional[Array[String]]`

The external assigned roles to the user.

##### `first_name`

Data type: `String`

The first name of the user.

##### `last_name`

Data type: `String`

The last name of the user.

##### `password`

Data type: `Variant[String[1], Sensitive[String[1]]]`

The password of the user.

##### `read_only`

Data type: `Boolean`

The status of the user if it is read only.

##### `roles`

Data type: `Array[String]`

The roles assigned to the user.

Default value: `["nx-anonymous"]`

##### `source`

Data type: `String`

The datasource of the user. e.g. local or ldap source name.

Default value: `default`

##### `status`

Data type: `Enum[active,disabled,changepassword]`

The user status.

Default value: `active`

#### Parameters

The following parameters are available in the `nexus_user` type.

* [`user_id`](#-nexus_user--user_id)

##### <a name="-nexus_user--user_id"></a>`user_id`

namevar

Data type: `String`

The login name of the user.

